summaryrefslogtreecommitdiffstats
path: root/kmail/imapaccountbase.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/imapaccountbase.h')
-rw-r--r--kmail/imapaccountbase.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/imapaccountbase.h b/kmail/imapaccountbase.h
index d9f3e7cb..4cca259f 100644
--- a/kmail/imapaccountbase.h
+++ b/kmail/imapaccountbase.h
@@ -267,9 +267,9 @@ namespace KMail {
/**
* Called when we're completely done checking mail for this account
* When @p seStatusMsg is true a status msg is shown
*/
- void postProcessNewMail( bool seStatusMsg = true );
+ void postProcessNewMail( bool setStatusMsg = true );
/**
* Check whether we're checking for new mail
@@ -267,9 +267,9 @@ namespace KMail {
/**
* Called when we're completely done checking mail for this account
- * When @p seStatusMsg is true a status msg is shown
+ * When @p setStatusMsg is true a status msg is shown
*/